==> react-native-pjt-ui-lib-0.3.0.tgz: package/src/button/Button.tsx <==
import React from 'react';
import {
  Platform,
  StyleSheet,
  Text,
  TouchableOpacity,
  TouchableNativeFeedback,
  TouchableWithoutFeedbackProps,
  View,
  StyleProp,
  ViewStyle,
  TextStyle,
  FlexStyle,
  ThemeAttributeBackgroundPropType,
  ViewProps
} from 'react-native';
import LinearGradient from 'react-native-linear-gradient';
import coalesceNonElementChildren from './coalesceNonElementChildren';

export interface LinearGradientProps extends ViewProps {
  colors?: (string | number)[];
  start?: { x: number; y: number };
  end?: { x: number; y: number };
  locations?: number[];
  useAngle?: boolean;
  angleCenter?: { x: number; y: number };
  angle?: number;
}

type allStyle = FlexStyle | ViewStyle | TextStyle | undefined | null;

/**
 * @prop disabled 是否禁止点击
 */
export interface touchableProps extends TouchableWithoutFeedbackProps {
  activeOpacity?: number; // 点击按钮时的透明度
  containerStyle?: allStyle; // 按钮外部容器样式
  disabledContainerStyle?: StyleProp<ViewStyle>; // 禁止点击时，外部容器样式
  androidBackground?: ThemeAttributeBackgroundPropType;
  childGroupStyle?: StyleProp<ViewStyle>;
  children?: React.ReactNode; // 按钮组件插槽
  allowFontScaling?: boolean; // 控制字体是否要根据系统的“字体大小”辅助选项来进行缩放
  type?: ButtonType; // 按钮类型
  linearGradientStyle?: LinearGradientProps; // 按钮渐变色样式，参考react-native-linear-gradient配置
  fontStyle?: StyleProp<TextStyle>; // 按钮字体样式
  fontDisabledStyle?: StyleProp<TextStyle>;
}

export type ButtonType = 'primary' | 'minor';

const systemButtonOpacity = 0.5;

export default function Button(props: touchableProps) {
  const touchableProps: touchableProps = {
    activeOpacity: _computeActiveOpacity(props)
  };

  let containerStyleByType = {};
  switch (props.type) {
    case 'primary':
      containerStyleByType = styles.btnPrimaryStyle;
      break;
    case 'minor':
      containerStyleByType = styles.btnMinorStyle;
      break;
    default:
      containerStyleByType = styles.btnPrimaryStyle;
      break;
  }

  const containerStyle: allStyle[] = [
    styles.btnBaseStyle,
    containerStyleByType,
    props.containerStyle,
    props.disabled ? styles.defaultDisabledContainerStyle : null,
    props.disabled ? props.disabledContainerStyle : null
  ];

  if (!props.disabled) {
    touchableProps.onPress = props.onPress;
    touchableProps.onPressIn = props.onPressIn;
    touchableProps.onPressOut = props.onPressOut;
    touchableProps.onLongPress = props.onLongPress;
    touchableProps.delayPressIn = props.delayPressIn;
    touchableProps.delayPressOut = props.delayPressOut;
    touchableProps.delayLongPress = props.delayLongPress;
  }
  if (Platform.OS === 'ios') {
    return (
      <TouchableOpacity
        {...touchableProps}
        testID={props.testID}
        style={containerStyle}
        accessibilityLabel={props.accessibilityLabel}
        accessibilityRole="button"
      >
        {_renderGroupedChildren(props)}
      </TouchableOpacity>
    );
  } else {
    const background = props.androidBackground
      ? props.androidBackground
      : TouchableNativeFeedback.SelectableBackground();

    let padding: number | string = 0;
    if (containerStyle[0] && containerStyle[0].padding) {
      padding = containerStyle[0].padding;
      const fixedStyle = Object.assign({}, containerStyle[0], { padding: 0 });
      containerStyle[0] = fixedStyle;
    }

    return (
      <View style={containerStyle}>
        <TouchableNativeFeedback
          {...touchableProps}
          style={{ flex: 1 }}
          testID={props.testID}
          accessibilityLabel={props.accessibilityLabel}
          accessibilityRole="button"
          background={background}
        >
          <View style={{ padding: padding }}>{_renderGroupedChildren(props)}</View>
        </TouchableNativeFeedback>
      </View>
    );
  }
}

function _computeActiveOpacity(props: touchableProps) {
  if (props.disabled) {
    return 1;
  }
  return props.activeOpacity !== null ? props.activeOpacity : systemButtonOpacity;
}

function _renderGroupedChildren(props: touchableProps) {
  const { disabled } = props;
  // 根据按钮类型选择按钮字体样式
  let fontText = {};
  switch (props.type) {
    case 'primary':
      fontText = styles.text;
      break;
    case 'minor':
      fontText = styles.minorText;
      break;
    default:
      fontText = styles.text;
      break;
  }
  // 配置是否禁止按钮的样式
  const style = [
    fontText,
    disabled ? styles.disabledText : null,
    props.fontStyle,
    disabled ? props.fontDisabledStyle : null
  ];

  const childGroupStyle = [styles.group, props.childGroupStyle];
  const children = coalesceNonElementChildren(props.children, (children, index) => {
    if (props.linearGradientStyle) {
      // 配置渐变样式
      const linearStyle = [props.linearGradientStyle.style];
      const linearGradientConfig = {
        start: { x: 0, y: 0 },
        end: { x: 1, y: 1 },
        colors: ['#FF3B2D', '#FF5E40'],
        ...props.linearGradientStyle,
        style: linearStyle
      };
      return (
        <LinearGradient {...linearGradientConfig}>
          <Text key={index} style={style} allowFontScaling={props.allowFontScaling}>
            {children}
          </Text>
        </LinearGradient>
      );
    } else {
      return (
        <Text key={index} style={style} allowFontScaling={props.allowFontScaling}>
          {children}
        </Text>
      );
    }
  });

  switch (children.length) {
    case 0:
      return null;
    case 1:
      return children[0];
    default:
      return <View style={childGroupStyle}>{children}</View>;
  }
}

const styles = StyleSheet.create({
  btnBaseStyle: {
    justifyContent: 'center',
    alignItems: 'center',
    width: 100,
    height: 40,
    borderRadius: 20
  },
  btnPrimaryStyle: {
    backgroundColor: '#f43'
  },
  btnMinorStyle: {
    backgroundColor: 'transparent',
    borderColor: '#ff542a',
    borderWidth: 1
  },
  minorText: {
    color: '#ff542a'
  },
  text: {
    color: '#fff',
    fontSize: 14,
    fontWeight: '500',
    textAlign: 'center'
  },
  disabledText: {
    color: '#f7c9bf'
  },
  defaultDisabledContainerStyle: {
    borderColor: '#f7c9bf'
  },
  group: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center'
  }
});

==> react-native-pjt-ui-lib-0.12.0.tgz: package/src/button/Button.tsx <==
import React from 'react';
import {
  Platform,
  StyleSheet,
  Text,
  TouchableOpacity,
  TouchableNativeFeedback,
  TouchableWithoutFeedbackProps,
  View,
  StyleProp,
  ViewStyle,
  TextStyle,
  FlexStyle,
  ThemeAttributeBackgroundPropType,
  ViewProps
} from 'react-native';
import LinearGradient from 'react-native-linear-gradient';
import coalesceNonElementChildren from './coalesceNonElementChildren';

export interface LinearGradientProps extends ViewProps {
  colors?: (string | number)[];
  start?: { x: number; y: number };
  end?: { x: number; y: number };
  locations?: number[];
  useAngle?: boolean;
  angleCenter?: { x: number; y: number };
  angle?: number;
}

type allStyle = FlexStyle | ViewStyle | TextStyle | undefined | null;

/**
 * @prop disabled 是否禁止点击
 */
export interface touchableProps extends TouchableWithoutFeedbackProps {
  activeOpacity?: number; // 点击按钮时的透明度
  containerStyle?: allStyle; // 按钮外部容器样式
  disabledContainerStyle?: StyleProp<ViewStyle>; // 禁止点击时，外部容器样式
  androidBackground?: ThemeAttributeBackgroundPropType;
  childGroupStyle?: StyleProp<ViewStyle>;
  children?: React.ReactNode; // 按钮组件插槽
  allowFontScaling?: boolean; // 控制字体是否要根据系统的“字体大小”辅助选项来进行缩放
  type?: ButtonType; // 按钮类型
  linearGradientStyle?: LinearGradientProps; // 按钮渐变色样式，参考react-native-linear-gradient配置
  fontStyle?: StyleProp<TextStyle>; // 按钮字体样式
  fontDisabledStyle?: StyleProp<TextStyle>;
}

export type ButtonType = 'primary' | 'minor';

const systemButtonOpacity = 0.5;

export default function Button(props: touchableProps) {
  const touchableProps: touchableProps = {
    activeOpacity: _computeActiveOpacity(props)
  };

  let containerStyleByType = {};
  switch (props.type) {
    case 'primary':
      containerStyleByType = styles.btnPrimaryStyle;
      break;
    case 'minor':
      containerStyleByType = styles.btnMinorStyle;
      break;
    default:
      containerStyleByType = styles.btnPrimaryStyle;
      break;
  }

  const containerStyle: allStyle[] = [
    styles.btnBaseStyle,
    containerStyleByType,
    props.containerStyle,
    props.disabled ? styles.defaultDisabledContainerStyle : null,
    props.disabled ? props.disabledContainerStyle : null
  ];

  if (!props.disabled) {
    touchableProps.onPress = props.onPress;
    touchableProps.onPressIn = props.onPressIn;
    touchableProps.onPressOut = props.onPressOut;
    touchableProps.onLongPress = props.onLongPress;
    touchableProps.delayPressIn = props.delayPressIn;
    touchableProps.delayPressOut = props.delayPressOut;
    touchableProps.delayLongPress = props.delayLongPress;
  }
  if (Platform.OS === 'ios') {
    return (
      <TouchableOpacity
        {...touchableProps}
        testID={props.testID}
        style={containerStyle}
        accessibilityLabel={props.accessibilityLabel}
        accessibilityRole="button"
      >
        {_renderGroupedChildren(props)}
      </TouchableOpacity>
    );
  } else {
    const background = props.androidBackground
      ? props.androidBackground
      : TouchableNativeFeedback.SelectableBackground();

    let padding: number | string = 0;
    if (containerStyle[0] && containerStyle[0].padding) {
      padding = containerStyle[0].padding;
      const fixedStyle = Object.assign({}, containerStyle[0], { padding: 0 });
      containerStyle[0] = fixedStyle;
    }

    return (
      <View style={containerStyle}>
        <TouchableNativeFeedback
          {...touchableProps}
          style={{ width: '100%', height: '100%' }}
          testID={props.testID}
          accessibilityLabel={props.accessibilityLabel}
          accessibilityRole="button"
          background={background}
        >
          <View style={{ padding: padding ,width: '100%', height: '100%',alignItems:'center' ,justifyContent:'center'}}>
            {_renderGroupedChildren(props)}
          </View>
        </TouchableNativeFeedback>
      </View>
    );
  }
}

function _computeActiveOpacity(props: touchableProps) {
  if (props.disabled) {
    return 1;
  }
  return props.activeOpacity !== null ? props.activeOpacity : systemButtonOpacity;
}

function _renderGroupedChildren(props: touchableProps) {
  const { disabled } = props;
  // 根据按钮类型选择按钮字体样式
  let fontText = {};
  switch (props.type) {
    case 'primary':
      fontText = styles.text;
      break;
    case 'minor':
      fontText = styles.minorText;
      break;
    default:
      fontText = styles.text;
      break;
  }
  // 配置是否禁止按钮的样式
  const style = [
    fontText,
    disabled ? styles.disabledText : null,
    props.fontStyle,
    disabled ? props.fontDisabledStyle : null
  ];

  const childGroupStyle = [styles.group, props.childGroupStyle];
  const children = coalesceNonElementChildren(props.children, (children, index) => {
    if (props.linearGradientStyle) {
      // 配置渐变样式
      const linearStyle = [props.linearGradientStyle.style];
      const linearGradientConfig = {
        start: { x: 0, y: 0 },
        end: { x: 1, y: 1 },
        colors: ['#FF3B2D', '#FF5E40'],
        ...props.linearGradientStyle,
        style: linearStyle
      };
      return (
        <LinearGradient {...linearGradientConfig}>
          <Text key={index} style={style} allowFontScaling={props.allowFontScaling}>
            {children}
          </Text>
        </LinearGradient>
      );
    } else {
      return (
        <Text key={index} style={style} allowFontScaling={props.allowFontScaling}>
          {children}
        </Text>
      );
    }
  });

  switch (children.length) {
    case 0:
      return null;
    case 1:
      return children[0];
    default:
      return <View style={childGroupStyle}>{children}</View>;
  }
}

const styles = StyleSheet.create({
  btnBaseStyle: {
    justifyContent: 'center',
    alignItems: 'center',
    width: 100,
    height: 40,
    borderRadius: 20
  },
  btnPrimaryStyle: {
    backgroundColor: '#f43'
  },
  btnMinorStyle: {
    backgroundColor: 'transparent',
    borderColor: '#ff542a',
    borderWidth: 1
  },
  minorText: {
    color: '#ff542a'
  },
  text: {
    color: '#fff',
    fontSize: 14,
    fontWeight: '500',
    textAlign: 'center'
  },
  disabledText: {
    color: '#f7c9bf'
  },
  defaultDisabledContainerStyle: {
    borderColor: '#f7c9bf'
  },
  group: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center'
  }
});
